@@ -1,6 +1,6 @@
 /*
 spacenavd - a free software replacement driver for 6dof space-mice.
-Copyright (C) 2007-2010 John Tsiombikas <nuclear@member.fsf.org>
+Copyright (C) 2007-2022 John Tsiombikas <nuclear@member.fsf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -28,21 +28,6 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <X11/Xutil.h>
 #endif
 
-struct client {
-	int type;
-
-	int sock;	/* UNIX domain socket */
-#ifdef USE_X11
-	Window win;	/* X11 client window */
-#endif
-
-	float sens;	/* sensitivity */
-	int dev_idx; /* device index */
-
-	struct client *next;
-};
-
-
 static struct client *client_list = NULL;
 static struct client *client_iter;	/* iterator (used by first/next calls) */
 
@@ -63,7 +48,7 @@ struct client *add_client(int type, void *cdata)
 		return 0;
 	}
 
-	if(!(client = malloc(sizeof *client))) {
+	if(!(client = calloc(1, sizeof *client))) {
 		return 0;
 	}
 
@@ -75,9 +60,13 @@ struct client *add_client(int type, void *cdata)
 		client->win = *(Window*)cdata;
 #endif
 	}
+	/* default to protocol version 0 until the client changes it */
+	client->proto = 0;
+	/* evmask for proto-v0 clients is just input events */
+	client->evmask = EVMASK_MOTION | EVMASK_BUTTON;
 
 	client->sens = 1.0f;
-	client->dev_idx = 0; /* default/first device */
+	client->dev = 0; /* default/first device */
 
 	if(!client_list && cfg.led == LED_AUTO) {
 		/* on first client, turn the led on */
@@ -96,7 +85,7 @@ void remove_client(struct client *client)
 
 	if(iter == client) {
 		client_list = iter->next;
-		free(iter);
+		free_client(iter);
 		iter = client_list;
 		if(!iter) {
 			if(cfg.led == LED_AUTO) {
@@ -110,13 +99,22 @@ void remove_client(struct client *client)
 		if(iter->next == client) {
 			struct client *tmp = iter->next;
 			iter->next = tmp->next;
-			free(tmp);
+			free_client(tmp);
 		} else {
 			iter = iter->next;
 		}
 	}
 }
 
+void free_client(struct client *client)
+{
+	if(client) {
+		free(client->name);
+		free(client->strbuf.buf);
+		free(client);
+	}
+}
+
 int get_client_type(struct client *client)
 {
 	return client->type;
@@ -144,14 +142,14 @@ float get_client_sensitivity(struct client *client)
 	return client->sens;
 }
 
-void set_client_device_index(struct client *client, int dev_idx)
+void set_client_device(struct client *client, struct device *dev)
 {
-	client->dev_idx = dev_idx;
+	client->dev = dev;
 }
 
-int get_client_device_index(struct client *client)
+struct device *get_client_device(struct client *client)
 {
-	return client->dev_idx;
+	return client->dev ? client->dev : get_devices();
 }
 
 struct client *first_client(void)
