@@ -139,9 +139,15 @@ int open_dev_serial(struct device *dev)
 	if(stty_sball(sb) == -1) {
 		goto err;
 	}
+
+	/* Apparently some spaceballs take some time to initialize, and it's
+	 * necessary to wait for a little while before we start sending commands.
+	 */
+	sleep(1);
+
 	write(fd, "\r@RESET\r", 8);
 
-	if((sz = read_timeout(fd, buf, sizeof buf - 1, 2000000)) > 0 && (buf[sz] = 0, strstr(buf, "\r@1"))) {
+	if((sz = read_timeout(fd, buf, sizeof buf - 1, 2000000)) > 0 && (buf[sz] = 0, strstr(buf, "@1"))) {
 		/* we got a response, so it's a spaceball */
 		make_printable(buf, sz);
 		logmsg(LOG_INFO, "Spaceball detected: %s\n", buf);
@@ -262,13 +268,9 @@ static int stty_sball(struct sball *sb)
 	return 0;
 }
 
-/* Logicad magellan spacemouse: 9600 8n1 CTS/RTS (see NOTE)
+/* Logicad magellan spacemouse: 9600 8n2 CTS/RTS
  * Since the magellan devices don't seem to send any newlines, we can rely on
  * canonical mode to feed us nice whole lines at a time.
- *
- * NOTE: the documentation specifies 2 stop bits instead of 1, but this seems to
- * cause incompatibilities with certain USB-serial converters, using one 1 stop
- * bit seems to work fine in all cases, so we'll go with that.
  */
 static int stty_mag(struct sball *sb)
 {
@@ -286,7 +288,7 @@ static int stty_mag(struct sball *sb)
 	term.c_cc[VERASE] = 0;
 	term.c_cc[VKILL] = 0;
 
-	term.c_cflag = CLOCAL | CREAD | CS8 | HUPCL;
+	term.c_cflag = CLOCAL | CREAD | CS8 | CSTOPB | HUPCL;
 #ifdef CCTS_OFLOW
 	term.c_cflag |= CCTS_OFLOW;
 #elif defined(CRTSCTS)
