@@ -1,6 +1,6 @@
 /*
 spacenavd - a free software replacement driver for 6dof space-mice.
-Copyright (C) 2007-2010 John Tsiombikas <nuclear@member.fsf.org>
+Copyright (C) 2007-2012 John Tsiombikas <nuclear@member.fsf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -16,13 +16,11 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#ifndef DEV_SERIAL_H_
-#define DEV_SERIAL_H_
+#ifndef SPNAV_DEV_SERIAL_H_
+#define SPNAV_DEV_SERIAL_H_
 
-#include "event.h"
+struct device;
 
-int open_dev_serial(const char *devfile);
-void close_dev_serial(void);
-int read_dev_serial(struct dev_input *inp);
+int open_dev_serial(struct device *dev);
 
-#endif	/* DEV_SERIAL_H_ */
+#endif	/* SPNAV_DEV_SERIAL_H_ */
