@@ -1,6 +1,6 @@
 /*
 spacenavd - a free software replacement driver for 6dof space-mice.
-Copyright (C) 2007-2013 John Tsiombikas <nuclear@member.fsf.org>
+Copyright (C) 2007-2022 John Tsiombikas <nuclear@member.fsf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -34,6 +34,11 @@ enum {
 	MOT_RX, MOT_RY, MOT_RZ
 };
 
+enum {
+	BTN_RELEASE = 0,
+	BTN_PRESS = 1
+};
+
 struct dev_event {
 	spnav_event event;
 	struct timeval timeval;
@@ -44,12 +49,16 @@ struct dev_event {
 
 static struct dev_event *add_dev_event(struct device *dev);
 static struct dev_event *device_event_in_use(struct device *dev);
+static void handle_button_action(int act, int val);
 static void dispatch_event(struct dev_event *dev);
 static void send_event(spnav_event *ev, struct client *c);
 static unsigned int msec_dif(struct timeval tv1, struct timeval tv2);
 
 static struct dev_event *dev_ev_list = NULL;
 
+static int disable_translation, disable_rotation;
+
+
 static struct dev_event *add_dev_event(struct device *dev)
 {
 	struct dev_event *dev_ev, *iter;
@@ -116,6 +125,21 @@ static struct dev_event *device_event_in_use(struct device *dev)
 	return NULL;
 }
 
+static inline int map_axis(int devaxis)
+{
+	const static int swaptab[] = {0, 2, 1, 3, 5, 4};
+
+	int axis = cfg.map_axis[devaxis];
+	if(axis < 0 || axis >= 6) {
+		return -1;
+	}
+
+	if(cfg.swapyz) {
+		return swaptab[axis];
+	}
+	return axis;
+}
+
 /* process_input processes an device input event, and dispatches
  * spacenav events to the clients by calling dispatch_event.
  * relative inputs (INP_MOTION) are accumulated, and dispatched when
@@ -124,19 +148,30 @@ static struct dev_event *device_event_in_use(struct device *dev)
  */
 void process_input(struct device *dev, struct dev_input *inp)
 {
-	int sign;
+	int sign, axis;
 	struct dev_event *dev_ev;
+	float sens_rot, sens_trans;
+	spnav_event ev;
 
 	switch(inp->type) {
 	case INP_MOTION:
-		inp->idx = cfg.map_axis[inp->idx];
+		ev.type = EVENT_RAWAXIS;
+		ev.axis.idx = inp->idx;
+		ev.axis.value = inp->val;
+		broadcast_event(&ev);
 
 		if(abs(inp->val) < cfg.dead_threshold[inp->idx] ) {
 			inp->val = 0;
 		}
-		sign = cfg.invert[inp->idx] ? -1 : 1;
+		if((axis = map_axis(inp->idx)) == -1) {
+			break;
+		}
+		sign = cfg.invert[axis] ? -1 : 1;
 
-		inp->val = (int)((float)inp->val * cfg.sensitivity * (inp->idx < 3 ? cfg.sens_trans[inp->idx] : cfg.sens_rot[inp->idx - 3]));
+		sens_rot = disable_rotation ? 0 : cfg.sens_rot[axis - 3];
+		sens_trans = disable_translation ? 0 : cfg.sens_trans[axis];
+
+		inp->val = (int)((float)inp->val * cfg.sensitivity * (axis < 3 ? sens_trans : sens_rot));
 
 		dev_ev = device_event_in_use(dev);
 		if(verbose && dev_ev == NULL)
@@ -147,11 +182,22 @@ void process_input(struct device *dev, struct dev_input *inp)
 		}
 		dev_ev->event.type = EVENT_MOTION;
 		dev_ev->event.motion.data = (int*)&dev_ev->event.motion.x;
-		dev_ev->event.motion.data[inp->idx] = sign * inp->val;
+		dev_ev->event.motion.data[axis] = sign * inp->val;
 		dev_ev->pending = 1;
 		break;
 
 	case INP_BUTTON:
+		ev.type = EVENT_RAWBUTTON;
+		ev.button.press = inp->val;
+		ev.button.bnum = inp->idx;
+		broadcast_event(&ev);
+
+		/* check to see if the button has been bound to an action */
+		if(cfg.bnact[inp->idx] > 0) {
+			handle_button_action(cfg.bnact[inp->idx], inp->val);
+			break;
+		}
+
 #ifdef USE_X11
 		/* check to see if we must emulate a keyboard event instead of a
 		 * retular button event for this button
@@ -206,6 +252,38 @@ void process_input(struct device *dev, struct dev_input *inp)
 	}
 }
 
+static void handle_button_action(int act, int pressed)
+{
+	if(pressed) return;	/* perform all actions on release */
+
+	switch(act) {
+	case BNACT_SENS_INC:
+		cfg.sensitivity *= 1.1f;
+		broadcast_cfg_event(REQ_GCFG_SENS, *(int*)&cfg.sensitivity);
+		break;
+	case BNACT_SENS_DEC:
+		cfg.sensitivity *= 0.9f;
+		broadcast_cfg_event(REQ_GCFG_SENS, *(int*)&cfg.sensitivity);
+		break;
+	case BNACT_SENS_RESET:
+		cfg.sensitivity = 1.0f;
+		broadcast_cfg_event(REQ_GCFG_SENS, *(int*)&cfg.sensitivity);
+		break;
+	case BNACT_DISABLE_ROTATION:
+		disable_rotation = !disable_rotation;
+		if(disable_rotation) {
+			disable_translation = 0;
+		}
+		break;
+	case BNACT_DISABLE_TRANSLATION:
+		disable_translation = !disable_translation;
+		if(disable_translation) {
+			disable_rotation = 0;
+		}
+		break;
+	}
+}
+
 int in_deadzone(struct device *dev)
 {
 	int i;
@@ -230,7 +308,7 @@ void repeat_last_event(struct device *dev)
 static void dispatch_event(struct dev_event *dev_ev)
 {
 	struct client *c, *client_iter;
-	int dev_idx;
+	struct device *client_dev;
 
 	if(dev_ev->event.type == EVENT_MOTION) {
 		struct timeval tv;
@@ -240,16 +318,43 @@ static void dispatch_event(struct dev_event *dev_ev)
 		dev_ev->timeval = tv;
 	}
 
-	dev_idx = get_device_index(dev_ev->dev);
 	client_iter = first_client();
 	while(client_iter) {
 		c = client_iter;
 		client_iter = next_client();
-		if(get_client_device_index(c) <= dev_idx) /* use <= until API changes, else == */
+
+		/* if the client has selected a single device to get input from, then
+		 * don't send the event if it originates from a different device
+		 */
+		client_dev = get_client_device(c);
+		if(!client_dev || client_dev == dev_ev->dev) {
 			send_event(&dev_ev->event, c);
+		}
 	}
 }
 
+void broadcast_event(spnav_event *ev)
+{
+	struct client *c;
+
+	c = first_client();
+	while(c) {
+		/* event masks will be checked at the protocol level (send_uevent) */
+		send_event(ev, c);
+		c = c->next;
+	}
+}
+
+void broadcast_cfg_event(int cfg, int val)
+{
+	spnav_event ev = {0};
+
+	ev.type = EVENT_CFG;
+	ev.cfg.cfg = cfg;
+	ev.cfg.data[0] = val;
+	broadcast_event(&ev);
+}
+
 static void send_event(spnav_event *ev, struct client *c)
 {
 	switch(get_client_type(c)) {
